@@ -6,7 +6,7 @@ from .. import filtersets
 
 
 class RiskListViewSet(NetBoxModelViewSet):
-    queryset = models.Risk.objects.prefetch_related('tags')
+    queryset = models.Risk.objects.prefetch_related('tagsx')
     serializer_class = RiskSerializer
 
 
@@ -14,3 +14,9 @@ class RiskRelationListViewSet(NetBoxModelViewSet):
     queryset = models.RiskRelation.objects.prefetch_related('tags')
     serializer_class = RiskRelationSerializer
 
+
+class RiskAssignmentViewSet(NetBoxModelViewSet):
+    queryset = models.RiskAssignment.objects.prefetch_related(
+        'object', 'risk', 'relation')
+    serializer_class = RiskAssignmentSerializer
+    filterset_class = filtersets.RiskAssignmentFilterSet
